Index: src/crankshaft/mips/lithium-codegen-mips.cc |
diff --git a/src/crankshaft/mips/lithium-codegen-mips.cc b/src/crankshaft/mips/lithium-codegen-mips.cc |
index ac40b2c337567ed3fe820419454d81ae3482ef5b..fa4ecf83098911ece462ad229e18cdbfbccc83d8 100644 |
--- a/src/crankshaft/mips/lithium-codegen-mips.cc |
+++ b/src/crankshaft/mips/lithium-codegen-mips.cc |
@@ -3095,12 +3095,14 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ Branch(&done, ne, result, Operand(scratch)); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex); |
__ lw(result, FieldMemOperand(result, Cell::kValueOffset)); |
- DeoptimizeIf(ne, instr, Deoptimizer::kHole, result, |
- Operand(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ DeoptimizeIf( |
+ ne, instr, Deoptimizer::kHole, result, |
+ Operand(Smi::FromInt(Isolate::kArrayElementsProtectorValid))); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
__ bind(&done); |
@@ -3095,12 +3095,14 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid. |
+ // Otherwise |
// it needs to bail out. |